@@ -5,6 +5,8 @@
     BangPatterns
   #-}
 
+{-# OPTIONS_GHC -fno-warn-simplifiable-class-constraints #-}
+
 module Data.Random.Distribution.Binomial where
 
 import Data.Random.Internal.TH
@@ -16,7 +18,7 @@ import Data.Random.Distribution.Uniform
 
 import Numeric.SpecFunctions ( stirlingError )
 import Numeric.SpecFunctions.Extra ( bd0 )
-import Numeric.Log ( log1p )
+import Numeric ( log1p )
 
     -- algorithm from Knuth's TAOCP, 3rd ed., p 136
     -- specific choice of cutoff size taken from gsl source
